<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="nb" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation type="vanished">Om</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategori:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Start torrent</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Hopp over sjekksummering</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Opprett undermappe</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Torrentbehandlingsmodus:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Ukategoriserte</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Legg til kategori …</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Fjern kategori</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Fjern ubrukte kategorier</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Gjenoppta torrenter</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Sett torrenter på pause</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Slett torrenter</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Rediger kategori …</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Avslutt qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>Kun én lenke per linje</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Global opplastingshastighetsgrense må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Global nedlastingshastighetsgrense må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativ opplastingshastighetsgrense må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternativ nedlastingshastighetsgrense må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maksimalt aktive nedlastinger må være større enn -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maksimalt aktive opplastinger må være større enn -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maksimalt aktive torrenter må være større enn -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Grensen for maksimalt antall tilkoblinger må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Grensen for maksimalt antall tilkoblinger per torrent må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Grensen for maksimalt antall opplastingsåpninger per torrent må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Ikke i stand til å lagre programinnstillinger, qBittorrent er sannsynligvis unåelig.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent på Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Ukjent</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Delingssforholdsgrense må være mellom 0 og 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Delingstidgrensen må være mellom 0 og 525600 minutter.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Porten som brukes for innkommende tilkoblinger må være mellom 1 og 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Porten som brukes for nettgrensesnittet må være mellom 1 og 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Ikke i stand til å logge inn, qBittorrent er sannsynligvis unåelig.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Ugyldig brukernavn eller passord.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Brukernavn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passord</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Logg inn</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Opphavspersoner</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Legg til</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Last opp torrenter</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Lagre filer i mappe:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Informasjonskapsel:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Velg mappe her</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Mer informasjon</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informasjon om sertifikater</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Velg plassering</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Begrens opplastingshastighet</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Begrens nedlastingshastighet</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Gi torrent nytt navn</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Annen …</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Mandag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Tirsdag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Onsdag</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Torsdag</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Fredag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Lørdag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>Søndag</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Logg ut</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Last ned torrenter fra der-tilhørende nettadresser eller magnetlenker</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Last opp lokal torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Er du sikker på at du vil slette valgte torrenter fra overføringslisten?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>qBittorrent er ikke oppnåelig</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Globalt antall opplastingsåpninger må være større enn 0 eller deaktivert.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Ugyldig kategorinavn:\nIkke bruk noen spesialtegn i kategorinavnet.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Kunne ikke opprette kategori</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Opplastingsforholdsgrense må være større enn 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Ledig plass: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Timer for Torrentaktivitet må være større enn 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Lagringsbehandling</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Nedlastingsforholdsgrense må være større enn 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent er avsluttet</translation>
    </message>
    <message>
        <source>Open documentation</source>
        <translation>Åpne dokumentasjon</translation>
    </message>
    <message>
        <source>Register to handle magnet links...</source>
        <translation>Registrer for å håndtere magnet-lenker …</translation>
    </message>
    <message>
        <source>Unable to add peers. Please ensure you are adhering to the IP:port format.</source>
        <translation>Klarte ikke legge til likemenn. Sørg for at du bruker formatet «IP:port».</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation>JavaScript kreves. Du må aktivere JavaScript for at nettgrensesnittet skal virke.</translation>
    </message>
    <message>
        <source>Name cannot be empty</source>
        <translation>Navnet kan ikke være tomt</translation>
    </message>
    <message>
        <source>Name is unchanged</source>
        <translation>Navnet er uendret</translation>
    </message>
    <message>
        <source>Failed to update name</source>
        <translation>Klarte ikke oppdatere navn</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Rediger</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Verktøy</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vis</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Alternativer …</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Gjenoppta</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Topp-verktøyslinje</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Statusfelt</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Hastighet i tittellinjen</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Doner!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Gjenoppta alle</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistikk</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Sett på pause</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Sett alt på pause</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Legg til torrentfil …</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentasjon</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Legg til torrentlenke …</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Global grense for opplastingshastighet</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Global grense for nedlastingshastighet</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Er du sikker på at du vil avslutte qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[↓: %1, ↑: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternative hastighetsgrenser</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Søkemotor</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtrer torrentliste …</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Overføringer</translation>
    </message>
    <message>
        <source>Move up in the queue</source>
        <translation>Flytt opp i køen</translation>
    </message>
    <message>
        <source>Move Up Queue</source>
        <translation>Flytt opp i køen</translation>
    </message>
    <message>
        <source>Bottom of Queue</source>
        <translation>Nederst i køen</translation>
    </message>
    <message>
        <source>Move to the bottom of the queue</source>
        <translation>Flytt nederst i køen</translation>
    </message>
    <message>
        <source>Top of Queue</source>
        <translation>Øverst i køen</translation>
    </message>
    <message>
        <source>Move Down Queue</source>
        <translation>Flytt ned i køen</translation>
    </message>
    <message>
        <source>Move down in the queue</source>
        <translation>Flytt ned i køen</translation>
    </message>
    <message>
        <source>Move to the top of the queue</source>
        <translation>Flytt øverst i køen</translation>
    </message>
    <message>
        <source>Your browser does not support this feature</source>
        <translation>Nettleseren din støtter ikke denne funksjonen</translation>
    </message>
    <message>
        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
        <translation>Nettgrensesnittet må brukes over HTTPS for å kunne bruke denne funksjonen.</translation>
    </message>
    <message>
        <source>Connection status: Firewalled</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Connected</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative speed limits: Off</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Download speed icon</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Alternative speed limits: On</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Upload speed icon</source>
        <translation type="unfinished" />
    </message>
    <message>
        <source>Connection status: Disconnected</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Alternativer</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Nedlastinger</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Tilkobling</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighet</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Nettgrensesnitt</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Språk</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Brukergrensesnittsspråk:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Epost-varsling ved nedlastingsfullførelse</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Kjør eksternt program ved ferdigstillelse av torrenter</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>IP-filtrering</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Planlegg bruken av alternative hastighetsgrenser</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Torrentkødanning</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Automatisk legg disse sporerne til nye nedlastinger:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Nettbrukergrenesnitt (fjernkontroll)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>IP-adresse:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Tjenerdomener:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Bruk HTTPS istedenfor HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Omgå autentisering for klienter på lokalvert</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Omgå autentisering for klienter i hvitlistede IP-subnett</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Oppdater mitt dynamiske domenenavn</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Behold ufullstendige torrenter i:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopier .torrent-filer til:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopier .torrent-filer for fullførte nedlastinger til:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Forhåndstildel diskplass for alle filer</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Tilføy .!qB benevnelse for ikke-fullførte filer</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Legg automatisk til torrenter fra:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>SMTP-tjener:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Denne tjeneren krever en sikker tilkobling (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentisering</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Brukernavn:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passord:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Aktivert protokoll:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP og μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Lytteport</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port brukt for innkommende tilkoblinger:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Bruk UPnP / NAT-PMP port-videresending fra min ruter</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Bruk ny port ved hver oppstart</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Tilkoblingsgrenser</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maksimalt antall tilkoblinger per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Globalt maksimumsantall for tilkoblinger:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maksimalt antall opplastingsåpninger per torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Globalt maksimumsantall for opplastingsåpninger:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Mellomtjener</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Type:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Ingen)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Vert:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Bruk mellomtjener for likemannstilkoblinger</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Bruk mellomtjener kun for torrenter</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Filtermappe (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Manuelt bannlyste IP-adresser…</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Bruk for sporere</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Globale hastighetsgrenser</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Opplasting:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Nedlasting:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternative hastighetsgrenser</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Fra:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Til:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Når:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Hver dag</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Ukedager</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Helger</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Innstillinger for hastighetsgrenser</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Bruk hastighetsgrense for transportering av tilleggsdata</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Bruk hastighetsgrense for µTP-protokoll</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Personvern</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Aktiver DHT (desentralisert nettverk) for å finne flere likemenn</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Skru på likemennsutveksling (PeX) for å finne flere likemenn</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Aktiver lokal likemannsoppdaging for å finne flere likemenn</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Krypteringsmodus:</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Krev kryptering</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Deaktiver kryptering</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Aktiver anonymitetsmodus</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Maksimalt antall aktive nedlastinger:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maksimalt antall aktive opplastinger:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maksimalt antall aktive torrenter:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Ikke ta med trege torrenter i regnskapet for disse grensene</translation>
    </message>
    <message>
        <source>then</source>
        <translation>deretter</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Bruk UPnP / NAT-PMP for å videresende porten fra min ruter</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Sertifikat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Nøkkel:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Registrer</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Domenenavn:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Støttede parametre (forskjell på små og store bokstaver):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Torrentnavn</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategori</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Innholdsmappe (samme som rotmappe for flerfilstorrenter)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Rotmappe (første undermappe for torrenter)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Lagringsmappe</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Antall filer</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Torrentstørrelse (Byte)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Nåværende sporer</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Informativ sjekksum</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Tips: Innkapsle parameter med anførselstegn for å unngå at teksten blir avskåret ved mellomrom (f.eks., "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Brukernavn for nettgrensesnittet må være minst 3 tegn.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Passordet for nettgrensesnittet må være minst 6 tegn.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Aktiver beskyttelse mot klikkoverstyring</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Skru på «Cross-Site Request Forgery»-beskyttelse (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Slett .torrentfiler etterpå</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Nedlastingsforholdsgrense:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Opplastingsforholdsgrense:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Endre gjeldende passord</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatisk</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Bruk et alternativt nettgrensesnitt</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Forvalgt lagringsmappe:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Filplasseringen til det alternative nettgrensesnittet kan ikke være blank.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Ikke start nedlastingen automatisk</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Bytt torrent til manuell modus</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Når torrentkategori endres:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Omplasser berørte torrenter</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Bruk hastighetsgrense for likemenn på lokalnett</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 betyr ubegrenset</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Flytt torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Når forvalgt lagringsmappe endres:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Skru på validering av «Host»-feltet i hodet</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Sikkerhet</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Når kategoriens lagringssti endres:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Opprett undermappe for torrenter med flerfoldige filer</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Bytt berørte torrenter til manuell modus</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Filenes plassering:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuell</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Torrent-inaktivitetsklokke:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Forvalgt torrentbehandlingsmodus:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Når en torrent legges til</translation>
    </message>
    <message>
        <source>Info: The password is saved unencrypted</source>
        <translation>Info: Passordet er lagret ukryptert</translation>
    </message>
    <message>
        <source>Strict super seeding:</source>
        <translation>Streng superdeling:</translation>
    </message>
    <message>
        <source>μTP-TCP mixed mode algorithm:</source>
        <translation>Algoritme for sammenblandet uTP-TCP-modus:</translation>
    </message>
    <message>
        <source>Upload rate based</source>
        <translation>Opplastingsforholdsbasert</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation>%G: Etiketter (adskilt med kommaer)</translation>
    </message>
    <message>
        <source>Socket backlog size:</source>
        <translation>Socket-køens størrelse:</translation>
    </message>
    <message>
        <source>Enable super seeding for torrent</source>
        <translation>Skru på superdeling av torrent</translation>
    </message>
    <message>
        <source>Prefer TCP</source>
        <translation>Foretrekk TCP</translation>
    </message>
    <message>
        <source>Outstanding memory when checking torrents:</source>
        <translation>Grense for minnebruk ved sjekk av torrenter:</translation>
    </message>
    <message>
        <source>Anti-leech</source>
        <translation>Anti-snylting</translation>
    </message>
    <message>
        <source>Enable OS cache:</source>
        <translation>Aktiver OS-hurtiglager:</translation>
    </message>
    <message>
        <source>When ratio reaches</source>
        <translation>Når forholdet når</translation>
    </message>
    <message>
        <source>When seeding time reaches</source>
        <translation>Når delingstiden når</translation>
    </message>
    <message>
        <source>Allow multiple connections from the same IP address:</source>
        <translation>Tillat flere tilkoblinger fra samme IP-adresse:</translation>
    </message>
    <message>
        <source>File pool size:</source>
        <translation>Filforrådets størrelse:</translation>
    </message>
    <message>
        <source>Any interface</source>
        <translation>Vilkårlig grensesnitt</translation>
    </message>
    <message>
        <source>Always announce to all tiers:</source>
        <translation>Alltid annonsér til alle nivåer:</translation>
    </message>
    <message>
        <source>Embedded tracker port:</source>
        <translation>Innebygd sporerport:</translation>
    </message>
    <message>
        <source>Optional IP Address to bind to (requires restart):</source>
        <translation>Valgfri IP-adresse å tilknytte seg til (krever omstart):</translation>
    </message>
    <message>
        <source>Fastest upload</source>
        <translation>Raskeste opplasting</translation>
    </message>
    <message>
        <source>Pause torrent</source>
        <translation>Sett torrent på pause</translation>
    </message>
    <message>
        <source>Remove torrent and its files</source>
        <translation>Fjern torrent og dens filer</translation>
    </message>
    <message>
        <source>qBittorrent Section</source>
        <translation>qBittorrent-seksjon</translation>
    </message>
    <message>
        <source>Send buffer watermark factor:</source>
        <translation>Send mellomlagringsvannmerkefaktor:</translation>
    </message>
    <message>
        <source>libtorrent Section</source>
        <translation>libtorrent-seksjon</translation>
    </message>
    <message>
        <source>Coalesce reads &amp; writes:</source>
        <translation>Bland sammen lesinger og skrivinger:</translation>
    </message>
    <message>
        <source>Outgoing ports (Min) [0: Disabled]:</source>
        <translation>Utgående porter (Min) [0: Deaktivert]:</translation>
    </message>
    <message>
        <source>IP Address to report to trackers (requires restart):</source>
        <translation>IP-adressen som skal rapporteres til sporere (krever omstart):</translation>
    </message>
    <message>
        <source>Recheck torrents on completion:</source>
        <translation>Gjennomsjekk torrenter på nytt ved fullførelse:</translation>
    </message>
    <message>
        <source>Allow encryption</source>
        <translation>Tillat kryptering</translation>
    </message>
    <message>
        <source>Send upload piece suggestions:</source>
        <translation>Send forslag om opplastingsdeler:</translation>
    </message>
    <message>
        <source>Disk cache:</source>
        <translation>Disk-hurtiglager:</translation>
    </message>
    <message>
        <source>Enable embedded tracker:</source>
        <translation>Aktiver innebygd sporer:</translation>
    </message>
    <message>
        <source>Remove torrent</source>
        <translation>Fjern torrent</translation>
    </message>
    <message>
        <source>Outgoing ports (Max) [0: Disabled]:</source>
        <translation>Utgående porter (Maks) [0: Deaktivert]:</translation>
    </message>
    <message>
        <source>Asynchronous I/O threads:</source>
        <translation>Usynkrone I/O-tråder:</translation>
    </message>
    <message>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <source>Send buffer watermark:</source>
        <translation>Send mellomlagringsvannmerke:</translation>
    </message>
    <message>
        <source>Disk cache expiry interval:</source>
        <translation>Utløpsintervall for hurtiglager på disk:</translation>
    </message>
    <message>
        <source>Peer proportional (throttles TCP)</source>
        <translation>Likemannsproporsjonalitet (Setter flaskehals på TCP)</translation>
    </message>
    <message>
        <source>Fixed slots</source>
        <translation>Fastsatte plasser</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avansert</translation>
    </message>
    <message>
        <source>min</source>
        <translation> min</translation>
    </message>
    <message>
        <source>Upload choking algorithm:</source>
        <translation>Kvelningsalgoritme for opplastninger:</translation>
    </message>
    <message>
        <source>Seeding Limits</source>
        <translation>Delegrenser</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>Round-robin</source>
        <translation>Rundgang</translation>
    </message>
    <message>
        <source>Upload slots behavior:</source>
        <translation>Oppførsel for opplastingsplasser:</translation>
    </message>
    <message>
        <source>Network Interface (requires restart):</source>
        <translation>Nettverksgrensesnitt (krever omstart):</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Send buffer low watermark:</source>
        <translation>Send lavt mellomlager-vannmerke:</translation>
    </message>
    <message>
        <source>Save resume data interval:</source>
        <translation>Intervall for lagring av gjenopptakelsesdata:</translation>
    </message>
    <message>
        <source>Always announce to all trackers in a tier:</source>
        <translation>Alltid annonsér til alle sporere på ett nivå:</translation>
    </message>
    <message>
        <source>Session timeout:</source>
        <translation>Tidsavbrudd for økt:</translation>
    </message>
    <message>
        <source>Resolve peer countries:</source>
        <translation>Finn fram til geografisk tilhørighet for likemenn:</translation>
    </message>
    <message>
        <source>ban for:</source>
        <translation>bannlys i:</translation>
    </message>
    <message>
        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
        <translation>La likemenn foretrekke nærliggende deler (krever libtorrent &gt;= 1.2.2):</translation>
    </message>
    <message>
        <source>Stop tracker timeout:</source>
        <translation>Tidsavbrudd for sporers stopp-hendelse:</translation>
    </message>
    <message>
        <source>Ban client after consecutive failures:</source>
        <translation>Bannlys klient etter påfølgende feil:</translation>
    </message>
    <message>
        <source>Enable cookie Secure flag (requires HTTPS)</source>
        <translation>Slå på Secure-flagget i informasjonskapsler (HTTPS)</translation>
    </message>
    <message>
        <source>UPnP lease duration [0: Permanent lease]:</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flagg</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Tilkobling</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Framdrift</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Ned-hastighet</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Opp-hastighet</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Nedlastet</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Opplastet</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Relevans</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Filer</translation>
    </message>
    <message>
        <source>Ban peer permanently</source>
        <translation>Bannlys likemann for godt</translation>
    </message>
    <message>
        <source>Are you sure you want to permanently ban the selected peers?</source>
        <translation>Er du sikker på at du vil bannlyse permanent de valgte likemennene?</translation>
    </message>
    <message>
        <source>Copy IP:port</source>
        <translation>Kopier IP:port</translation>
    </message>
    <message>
        <source>Add a new peer...</source>
        <translation>Legg til ny likemann …</translation>
    </message>
    <message>
        <source>Country/Region</source>
        <translation>Land/region</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normal</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Høy</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maksimal</translation>
    </message>
    <message>
        <source>Mixed</source>
        <translation>Blandet</translation>
    </message>
    <message>
        <source>Do not download</source>
        <translation>Ikke last ned</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Sporere</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Likemenn</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>HTTP-kilder</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Innhold</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Nedlastet:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Overføring</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktivitetstid:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>Gjenværende tid:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Opplastet:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Delere:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Nedlastingshastighet:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Opplastingshastighet:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Likemenn:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Nedlastingsgrense:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Opplastingsgrense:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Ødslet:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Tilkoblinger:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informasjon</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Delingsforhold:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Reannonsering om:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Sist sett fullført:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Total størrelse:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Deler:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Opprettet av:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Lagt til:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Fullført:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Opprettet:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Torrent-sjekksum:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Lagringsmappe:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Aldri</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (har %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (%2 denne økta)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (%2 maks)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (%2 totalt)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (%2 gj.sn.)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Nedlastingsgrense:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Opplastingsgrense:</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Prioritet</translation>
    </message>
    <message>
        <source>Filter files...</source>
        <translation>Filtrer filer …</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Gi nytt navn …</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Overvåket mappe</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Overstyr lagringsplassering</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Overvåket mappe</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Forvalgt lagringsplass</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statistikk</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Brukerstatistikk</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Hurtiglager-statistikk</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Treff i lesehurtiglager:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Gjennomsnittlig tid i kø:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Tilkoblede likemenn:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Totalt deleforhold:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Totalt nedlastet:</translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Økts-ødsling:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Totalt opplastet:</translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Total bufferstørrelse:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Ytelesesstatistikk</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Inn- ut -jobber i kø:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Overlast i skrivingshurtiglager:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Overlast i lesingshurtiglager:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Total køstørrelse:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>DHT: %1 noder</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Alle (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Laster ned (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Deler (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Fullførte (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Gjenopptatte (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Satt på pause (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktive (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Inaktive (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Feilede (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Alle (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Laster ned (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Deler (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Fullførte (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Satt på pause (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Gjenopptatte (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktive (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Inaktive (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Feilede (%1)</translation>
    </message>
    <message>
        <source>Stalled Uploading (%1)</source>
        <translation>Laster ikke opp (%1)</translation>
    </message>
    <message>
        <source>Stalled Downloading (%1)</source>
        <translation>Laster ikke ned (%1)</translation>
    </message>
    <message>
        <source>Stalled Downloading (0)</source>
        <translation>Laster ikke ned (0)</translation>
    </message>
    <message>
        <source>Stalled (0)</source>
        <translation>Laster ikke ned (0)</translation>
    </message>
    <message>
        <source>Stalled Uploading (0)</source>
        <translation>Laster ikke opp (0)</translation>
    </message>
    <message>
        <source>Stalled (%1)</source>
        <translation>Laster ikke ned (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    </context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Størrelse</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Ferdig</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Delere</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Likemenn</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Ned-hastighet</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Opp-hastighet</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Forhold</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>Gjenværende tid</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketter</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Lagt til</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Fullført</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Sporer</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Ned-grense</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Opp-grense</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Nedlastet</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Opplastet</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Nedlastet denne økta</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Opplastet denne økta</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Gjenstående</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktivitetstid</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Lagringsmappe</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Fullført</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Forholdsgrense</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Sist sett i fullført tilstand</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Siste aktivitet</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Total størrelse</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Tilgjengelighet</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>Nettadresse</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Likemenn</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Melding</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Nedlastet</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Nettadresse til sporer:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Oppdaterer …</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Virker</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Deaktivert</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Ikke kontaktet ennå</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Irrelevant</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Delere</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Virker ikke</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopier sporerens nettadresse</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Legg til en ny sporer …</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Rediger sporerens nettadresse …</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Sporer-redigering</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Snyltere</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Fjern sporer</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Gjenstående</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Tilgjengelighet</translation>
    </message>
    <message>
        <source>Tier</source>
        <translation>Nivå</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Nedlastingsprioritet</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Framdrift</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Tilleggingsdialog for sporere</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Liste over sporere som skal legges til (én per linje):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 siden</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Tildeler</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Pauset</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Fullført</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Flytter</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[F] Deler</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Deler</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>I kø</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Feilet</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[F] Laster ned</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Laster ned metadata</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Kontrollerer</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Mangler filer</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>Plassert i kø for gjennomsjekking</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Laster ned</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Sjekker gjennopptakingsdata</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Laster ikke ned</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorier</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketter</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Hastighetsbegrensning for torrentnedlasting</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Hastighetsbegrensning for torrentopplasting</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Gi nytt navn</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Gjenoppta</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Påtving gjenopptakelse</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Sett på pause</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Slett</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Begrens delingsforhold …</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Begrens opplastingshastighet …</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Begrens nedlastingshastighet …</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Flytt oppover</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Flytt nedover</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Flytt til toppen</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Flytt til bunnen</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Velg plassering …</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Last ned de første og siste delene først</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatisk torrentbehandling</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Ny …</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Tilbakestill</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Påtving ny gjennomsjekk</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Superdelingsmodus</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Gi nytt navn …</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Last ned i rekkefølge</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Påtving ny gjennomsjekk</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Ny kategori</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Plassering</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nytt navn</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Angi plassering</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Tving reannonsering</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Rediger kategori</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Lagringssti</translation>
    </message>
    <message>
        <source>Comma-separated tags:</source>
        <translation>Kommaseparerte etiketter:</translation>
    </message>
    <message>
        <source>Add Tags</source>
        <translation>Legg til etiketter</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Etiketter</translation>
    </message>
    <message>
        <source>Magnet link</source>
        <translation>Magnetlenke</translation>
    </message>
    <message>
        <source>Hash</source>
        <translation>Sjekksum</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation>Fjern alle</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Queue</source>
        <translation>Kø</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Legg til …</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Forholdsbegrensning for torrent-opp-/ned-lasting</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Bruk global delingsforholdsgrense</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Fri forholdsgrense</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Sett delingsgrense til</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>forhold</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minutter</translation>
    </message>
</context>
<context>
    <name>about</name>
    </context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Slett bekreftelse</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Slett filene på harddisken samtidig</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Slettingsbekreftelse - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Last ned fra nettadresser</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Legg til torrentlenke …</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1t %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2t</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Ukjent</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Lagringsstien kan ikke være tom</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Sti til programtillegg:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>Nettadresse eller lokal mappe</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Installer programtillegg</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Delere:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Alle programtillegg</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Søk</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Søk i programtillegg …</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Alle kategorier</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Søk i:</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Resultater (viser</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filter</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Kun torrentnavn</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Kun aktiverte</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>av</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Overalt</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Avinstaller</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Installer nytt programtillegg</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Du kan hente nye søkemotor-programtillegg her:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Installerte søketillegg:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktivert</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Advarsel: Sørg for å overholde ditt lands opphavsrettslovgivning når du laster ned torrenter fra noen av disse søkemotorene.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Se etter oppdateringer</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Søketillegg</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Snyltere</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Søkemotor</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Delere</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Aktivert</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versjon</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nei</translation>
    </message>
</context>
<context>
    <name>PeersAdditionDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <source>Add Peers</source>
        <translation>Legg til likemenn</translation>
    </message>
    <message>
        <source>List of peers to add (one IP per line):</source>
        <translation>Liste over likemenn som skal legges til (Én IP per linje):</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Format: IPv4:port / [IPv6]:port</source>
        <translation>Format: IPv4:port / [IPv6]:port</translation>
    </message>
</context>
<context>
    <name>TagFilterWidget</name>
    <message>
        <source>New Tag</source>
        <translation>Ny etikett</translation>
    </message>
    <message>
        <source>Add tag...</source>
        <translation>Legg til etikett …</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Slett torrenter</translation>
    </message>
    <message>
        <source>Tag:</source>
        <translation>Etikett:</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Sett torrenter på pause</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Gjenoppta torrenter</translation>
    </message>
    <message>
        <source>Remove unused tags</source>
        <translation>Fjern ubrukte etiketter</translation>
    </message>
    <message>
        <source>Invalid tag name</source>
        <translation>Ugyldig etikettnavn</translation>
    </message>
    <message>
        <source>Remove tag</source>
        <translation>Fjern etikett</translation>
    </message>
</context>
<context>
    <name>TagFilterModel</name>
    <message>
        <source>All</source>
        <translation>Alle</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Umerket</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>Bug Tracker:</source>
        <translation>Feilsporer:</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>E-mail:</source>
        <translation>E-post:</translation>
    </message>
    <message>
        <source>Current maintainer</source>
        <translation>Nåværende vedlikeholder</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Hjemmeside:</translation>
    </message>
    <message>
        <source>Greece</source>
        <translation>Hellas</translation>
    </message>
    <message>
        <source>Special Thanks</source>
        <translation>Spesiell takk til</translation>
    </message>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>En avansert BitTorrent-klient programmert i C++, basert på Qt toolkit og libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Navn:</translation>
    </message>
    <message>
        <source>About qBittorrent</source>
        <translation>Om qBittorrent</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Oversettere</translation>
    </message>
    <message>
        <source>qBittorrent was built with the following libraries:</source>
        <translation>qBittorrent ble bygd med følgende biblioteker:</translation>
    </message>
    <message>
        <source>Nationality:</source>
        <translation>Nasjonalitet:</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Opphavsperson</translation>
    </message>
    <message>
        <source>Software Used</source>
        <translation>Programvare som er brukt</translation>
    </message>
    <message>
        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
        <translation>DB-IPs fritt tilgjengelige IP-til-land-database brukes for å slå opp likemennenes opphavsland. Denne databasen er lisensiert under Creative Commons Navngivelse 4.0 Internasjonal.</translation>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>All addresses</source>
        <translation>Alle adresser</translation>
    </message>
    <message>
        <source>All IPv6 addresses</source>
        <translation>Alle IPv6-adresser</translation>
    </message>
    <message>
        <source>All IPv4 addresses</source>
        <translation>Alle IPv4-adresser</translation>
    </message>
</context>
<context>
    <name>SearchJobWidget</name>
    <message>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Last ned</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Navn</translation>
    </message>
    <message>
        <source>Description page URL</source>
        <translation>Adressen til beskrivelsessiden</translation>
    </message>
    <message>
        <source>Open description page</source>
        <translation>Åpne beskrivelsesside</translation>
    </message>
    <message>
        <source>Download link</source>
        <translation>Nedlastingslenke</translation>
    </message>
</context>
<context>
    <name>TorrentContentTreeView</name>
    <message>
        <source>Renaming</source>
        <translation>Gir nytt navn</translation>
    </message>
    <message>
        <source>New name:</source>
        <translation>Nytt navn:</translation>
    </message>
</context>
</TS>